{% load l10n %}

<h3><a href="{{ event.get_absolute_url }}">{{ event.title }}</a></h3>
<p>
    <span>{{ event.start_date|localize }}</span> /
    <span>{{ event.category.get_translation.title }}</span>
</p>
