{% extends "base.html" %}
{% load i18n placeholder_tags %}

{% block main %}
<a href="{% url "multilingual_events_list" %}">{% trans "Back to Events" %}</a>
<h1>{{ event.title }}</h1>
<p>{{ event.description }}<p>

{% render_placeholder event.content %}
{% render_placeholder event.detailed_description %}

{% endblock %}
